Inventory of changes in auxiliary data across measures
compare_aux_releases.RdCompares auxiliary data files between the current and a previous release across one or more measures.
Usage
compare_aux_releases(
measure = NULL,
maindir = getOption("pipaux.working_dir"),
owner = "PIP-Technical-Team",
old_release = NULL,
verbose = FALSE,
...
)Arguments
- measure
Optional character vector. Specific measures to check (e.g.,
c("cpi", "gdp")). IfNULL, all available measures are included.- maindir
Path to the local auxiliary data directory. Defaults to
getOption("pipaux.working_dir").- owner
GitHub owner of aux data repos. Defaults to
"PIP-Technical-Team".- old_release
Character. The identifier of the previous release to compare against (e.g.,
"20240101_PROD"). If NULL, automatically take last available release of same identity as the current working release- verbose
Logical. If
TRUE, displays messages in the console.- ...
Additional arguments passed to
get_aux_changes().