Load any auxiliary data
load_aux.RdLoad any auxiliary data
Usage
load_aux(
measure,
maindir = getOption("pipaux.working_dir"),
apply_label = TRUE,
ppp_defaults = TRUE,
branch = NULL
)Arguments
- measure
character: measure to be loaded
- maindir
character: Main directory of project.
- apply_label
logical: If TRUE, predefined labels will applied.
- ppp_defaults
logical: If TRUE, wider format ppp data will be returned
- branch
GitHub branch to use. By default, this is the release branch set in your R session. To ensure correct behavior, call
pipfun::setup_working_release()once per session, followed bypipfun::get_wrk_release()to retrieve the active release. These steps ensure the function uses the correct release branch (e.g.,"release_2024Q1"). Alternatively, you can explicitly specify other branches among"DEV","PROD", or"main"if needed