General auxiliary function
aux_fun.RdUpdate any auxiliary data
Arguments
- measure
character: Name of the measure to process
- repo
character: Name of the GitHub repository containing the auxiliary data Defaults to
"aux_<measure>"unlessmeasureis"income_groups"or"country_list", in which case it defaults to"Class".- owner
character: GitHub repository owner. Default is
getOption("pipfun.ghowner")- maindir
character: Main directory of the project. Default is
getOption("pipaux.working_dir")- processed
environment: Environment that keeps track of already processed measures to avoid redundant processing. Default is a new empty environment
- force
logical: If
TRUE, forces an update even if the data appears up to date. Default isFALSE- tag
character: Specifies the GitHub branch tag for versioning. Defaults to
release_branch, which is determined from the working release- log
logical, defaults to TRUE. Enables or disables logging in "pipaux_log"
- ...
Additional arguments passed to the auxiliary function handling the measure