Compare auxiliary data files across releases
get_aux_changes.RdThis function compares the contents of auxiliary data files between the current and a specified previous release. It identifies differences for specified key variables
Arguments
- measure
character: Name of the measure to process
- maindir
character: Main directory of the project. Default is
getOption("pipaux.working_dir")- old_release
Character. The identifier of the previous release to compare against (e.g.,
"20240101_PROD"). If NULL, automatically take last available release of same identity as the current working release- key_cols
Character vector. Variables used as keys to compare values between releases. Defaults to the
pipaux.key_varsoption.- verbose
Logical. If
TRUE, displays messages in the console.